searchData={"items":[{"type":"module","title":"Francis","doc":"Module responsible for starting the Francis server and to wrap the Plug functionality\n\nThis module performs multiple tasks:\n  * Uses the Application module to start the Francis server\n  * Defines the Francis.Router which uses Francis.Plug.Router, :match and :dispatch\n  * Defines the macros get, post, put, delete, patch and ws to define routes for each operation\n\nYou can also set the following options:\n  * :bandit_opts - Options to be passed to Bandit\n  * :plugs - List of plugs to be used by Francis","ref":"Francis.html"},{"type":"macro","title":"Francis.delete/2","doc":"Defines a DELETE route","ref":"Francis.html#delete/2"},{"type":"macro","title":"Examples - Francis.delete/2","doc":"```\ndefmodule Example.Router do\n  use Francis\n\n  delete \"/hello\", fn conn ->\n    \"Hello World!\"\n  end\nend\n```","ref":"Francis.html#delete/2-examples"},{"type":"macro","title":"Francis.get/2","doc":"Defines a GET route","ref":"Francis.html#get/2"},{"type":"macro","title":"Examples - Francis.get/2","doc":"```\ndefmodule Example.Router do\n  use Francis\n\n  get \"/hello\", fn conn ->\n    \"Hello World!\"\n  end\nend\n```","ref":"Francis.html#get/2-examples"},{"type":"macro","title":"Francis.patch/2","doc":"Defines a PATCH route","ref":"Francis.html#patch/2"},{"type":"macro","title":"Examples - Francis.patch/2","doc":"```elixir\ndefmodule Example.Router do\n  use Francis\n\n  patch \"/hello\", fn conn ->\n    \"Hello World!\"\n  end\nend\n```","ref":"Francis.html#patch/2-examples"},{"type":"macro","title":"Francis.post/2","doc":"Defines a POST route","ref":"Francis.html#post/2"},{"type":"macro","title":"Examples - Francis.post/2","doc":"```\ndefmodule Example.Router do\n  use Francis\n\n  post \"/hello\", fn conn ->\n    \"Hello World!\"\n  end\nend\n```","ref":"Francis.html#post/2-examples"},{"type":"macro","title":"Francis.put/2","doc":"Defines a PUT route","ref":"Francis.html#put/2"},{"type":"macro","title":"Examples - Francis.put/2","doc":"```\ndefmodule Example.Router do\n  use Francis\n\n  put \"/hello\", fn conn ->\n    \"Hello World!\"\n  end\nend\n```","ref":"Francis.html#put/2-examples"},{"type":"macro","title":"Francis.unmatched/1","doc":"Defines an action for umatched routes and returns 404","ref":"Francis.html#unmatched/1"},{"type":"macro","title":"Francis.ws/2","doc":"Defines a WebSocket route that sends text type responses","ref":"Francis.html#ws/2"},{"type":"macro","title":"Examples - Francis.ws/2","doc":"```elixir\ndefmodule Example.Router do\n  use Francis\n\n  ws \"/hello\", fn _ ->\n    \"Hello World!\"\n  end\nend\n```","ref":"Francis.html#ws/2-examples"},{"type":"module","title":"Francis.Plug.Router","doc":"Module that imports required macros from Francis and Plug.Router","ref":"Francis.Plug.Router.html"},{"type":"module","title":"Francis.Watcher","doc":"Watcher mode for development that checks modified time of your files and recompiles them","ref":"Francis.Watcher.html"},{"type":"function","title":"Francis.Watcher.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Francis.Watcher.html#child_spec/1"},{"type":"function","title":"Francis.Watcher.init/1","doc":"","ref":"Francis.Watcher.html#init/1"},{"type":"function","title":"Francis.Watcher.start_link/1","doc":"","ref":"Francis.Watcher.html#start_link/1"},{"type":"task","title":"mix francis.release","doc":"Generates files for Francis deployment in multiple environments.","ref":"Mix.Tasks.Francis.Release.html"},{"type":"task","title":"Command line options - mix francis.release","doc":"* `docker` - Generates Docker and .dockerignore for deployment\n  * `port` - Port to be exposed in Docker container (port=4001) . Defaults to 4000","ref":"Mix.Tasks.Francis.Release.html#module-command-line-options"},{"type":"callback","title":"Mix.Tasks.Francis.Release.generate_files/1","doc":"","ref":"Mix.Tasks.Francis.Release.html#c:generate_files/1"},{"type":"task","title":"mix francis.release.docker","doc":"Generates Docker and .dockerignore for deployment","ref":"Mix.Tasks.Francis.Release.Docker.html"},{"type":"task","title":"mix francis.server","doc":"Starts the application by configuring all endpoints servers to run.\n\nNote: to start the endpoint without using this mix task you must set\n`server: true` in your `Phoenix.Endpoint` configuration.","ref":"Mix.Tasks.Francis.Server.html"},{"type":"task","title":"Command line options - mix francis.server","doc":"Task accepts the same command-line options as `mix run`.\n\nThe `--no-halt` flag is automatically added.","ref":"Mix.Tasks.Francis.Server.html#module-command-line-options"},{"type":"extras","title":"Francis","doc":"# Francis\n\n[![Hex version badge](https://img.shields.io/hexpm/v/francis.svg)](https://hex.pm/packages/francis)\n[![License badge](https://img.shields.io/hexpm/l/repo_example.svg)](https://github.com/filipecabaco/francis/blob/master/LICENSE.md)\n[![Elixir CI](https://github.com/filipecabaco/francis/actions/workflows/elixir.yaml/badge.svg)](https://github.com/filipecabaco/francis/actions/workflows/elixir.yaml)\n\nSimple boilerplate killer using Plug and Bandit inspired by\n[Sinatra](https://sinatrarb.com) for Ruby","ref":"readme.html"},{"type":"extras","title":"Installation - Francis","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `francis` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:francis, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Francis","doc":"To start the server up you can run `mix francis.server` or if you need a iex\nconsole you can run with `iex -S mix francis.server`","ref":"readme.html#usage"},{"type":"extras","title":"Watcher - Francis","doc":"If you want to have a watcher that will reload the server when you change your code:\n\n```elixir\nimport Config\n\nconfig :francis, watcher: true\n```\n\nIt defaults to `false`","ref":"readme.html#watcher"},{"type":"extras","title":"Example of a router - Francis","doc":"```elixir\ndefmodule Example do\n  use Francis\n\n  get(\"/\", fn _ -> \" world \" end)\n  get(\"/:name\", fn %{params: %{\"name\" => name}} -> \"hello #{name}\" end)\n\n  ws(\"ws\", fn \"ping\" -> \"pong\" end)\n\n  unmatched(fn _ -> \"not found\" end)\nend\n```\n\nAnd in your `mix.exs` file add that this module should be the one used for\nstartup:\n\n```\ndef application do\n   [\n     extra_applications: [:logger],\n     mod: {Example, []}\n   ]\n end\n```\n\nThis will ensure that Mix knows what module should be the entrypoint.","ref":"readme.html#example-of-a-router"},{"type":"extras","title":"Example of a router with Plugs - Francis","doc":"With the `plugs` option you are able to apply a list of plugs that happen\nbetween before dispatching the request.\n\nIn the following example we're adding the `Plug.BasicAuth` plug to setup basic\nauthentication on all routes\n\n```elixir\ndefmodule Example do\n  import Plug.BasicAuth\n\n  use Francis, plugs: [{:basic_auth, username: \"test\", password: \"test\"}]\n\n  get(\"/\", fn _ -> \" world \" end)\n  get(\"/:name\", fn %{params: %{\"name\" => name}} -> \"hello #{name}\" end)\n\n  ws(\"ws\", fn \"ping\" -> \"pong\" end)\n\n  unmatched(fn _ -> \"not found\" end)\nend\n```","ref":"readme.html#example-of-a-router-with-plugs"},{"type":"extras","title":"Example using it with Mix.install - Francis","doc":"In your `iex` instance run:\n\n```elixir\nMix.install([{:francis, \"~> 0.1\"}])\n\ndefmodule Example do\n  use Francis\n\n  get(\"/\", fn _ -> \" world \" end)\n  get(\"/:name\", fn %{params: %{\"name\" => name}} -> \"hello #{name}\" end)\n\n  ws(\"ws\", fn \"ping\" -> \"pong\" end)\n\n  unmatched(fn _ -> \"not found\" end)\n\n  def start(_, _) do\n    children = [{Bandit, [plug: __MODULE__]}]\n    Supervisor.start_link(children, strategy: :one_for_one)\n  end\nend\n\nExample.start()\n```\n\nCheck the folder\n[example](https://github.com/filipecabaco/francis/tree/main/example) to check\nthe code.","ref":"readme.html#example-using-it-with-mix-install"}],"content_type":"text/markdown","proglang":"elixir","producer":{"name":"ex_doc","version":"0.37.3"}}